<?php
/*
Plugin Name: Picasa Express x2
Plugin URI: http://wott.net.ru/picasa-express
Description: Browse, search and select photos from any publicly available Picasa Web Album and add them to your post/pages.
Version: 1.1
Author: Wott
Author URI: http://wott.net.ru/

Thank you to Scrawl ( scrawl@psytoy.net ) for plugin Picasa Image Express 2.0 RC2
for main idea and Picasa icons

Copyright 2010 Wott ( email : wotttt@gmail.com )

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

define( 'PE2_VERSION', '1.1' );

if (!class_exists("PicasaExpressX2")) {
	class PicasaExpressX2 {

		// Define options and default values
		private $options = array(
			'pe2_configured'        => false,
			'pe2_icon'              => 1,
			'pe2_user_name'         => 'undefined',

			'pe2_caption'           => 0,
			'pe2_title'             => 1,
			'pe2_link'              => 'thickbox',

			'pe2_img_align'         => 'left',
			'pe2_img_css'           => '',
			'pe2_img_style'         => '',

			'pe2_gal_align'         => 'left',
			'pe2_gal_css'           => '',
			'pe2_gal_style'         => '',

			'pe2_img_sort'          => 0,
			'pe2_img_asc'           => 1,

			'pe2_gal_order'         => 0,
		);

		// plugin URL
		private $plugin_URL;

		function __construct() {
			// Hook for plugin de/activation
			register_activation_hook( __FILE__, array (&$this, 'init_options' ) );
			register_deactivation_hook( __FILE__, array (&$this, 'delete_options' ) );

			// Retrieve plugin options from database if plugin configured
			if (!$this->options['pe2_configured']) {
				// get plugin URL
				$this->plugin_URL = WP_PLUGIN_URL.'/'.dirname(plugin_basename(__FILE__));

				foreach ($this->options as $key => $option) {
					$this->options[$key] = get_option($key,$option);
				}

				if ($this->options['pe2_configured']) {
				if (is_admin()) {

					// loading localization if exist
					add_action('init', array(&$this, 'load_textdomain'));

					// Add settings to the plugins management page under
					add_filter('plugin_action_links_'.plugin_basename(__FILE__), array(&$this, 'add_settings_link'));

					// Add media button to editor
					add_action('media_buttons', array(&$this, 'add_media_button'), 20);
					// Add iframe page creator
					add_action('media_upload_picasa', array(&$this, 'media_upload_picasa'));

					// AJAX request from media_upload_picasa iframe script ( pe2-scripts.js )
					add_action('wp_ajax_pe2_get_gallery', array(&$this, 'get_gallery'));
					add_action('wp_ajax_pe2_get_images', array(&$this, 'get_images'));

					// Add a page which will hold the  Options form
					add_action('admin_menu', array(&$this, 'add_settings_page'));

				} else {

					/* Attach stylesheet in the user page
					 * you can enable attach styles if define some special
					 */
					// add_action('wp_head', array(&$this, 'add_style'));

					add_shortcode('pe2-gallery', array(&$this, 'gallery_shortcode'));
					add_shortcode('clear', array(&$this, 'clear_shortcode'));
				}
				}
			}

		}

		function init_options() {
			add_option('pe2_configured',true);
		}

		function delete_options() {
			delete_option('pe2_configured');
		}

		function load_textdomain() {
			if ( function_exists('load_plugin_textdomain') ) {
				load_plugin_textdomain('pe2', PLUGINDIR.'/'.dirname(plugin_basename(__FILE__)));
			}
		}

		function add_media_button() {

			$plugin_URL = $this->plugin_URL;
			$icon = $this->options['pe2_icon'];
			// 'type=picasa' => 'media_upload_picasa' action above
			$media_picasa_iframe_src = "media-upload.php?type=picasa&tab=type&TB_iframe=true&width=640&height=566";
			$media_picasa_title = __("Add Picasa image or gallery", 'pe2');

			echo "<a href=\"$media_picasa_iframe_src\" class=\"thickbox\" title=\"$media_picasa_title\"><img src=\"$plugin_URL/icon_picasa$icon.gif\" alt=\"$media_picasa_title\" /></a>";
		}

		function media_upload_picasa() {

			// add script and style for dialog
			add_action('admin_print_styles', array(&$this, 'add_style'));
			add_action('admin_print_scripts', array(&$this, 'add_script'));

			// we do not need default script for media_upload
			wp_deregister_script('swfupload-all');
			wp_deregister_script('swfupload-handlers');
			wp_deregister_script('image-edit');
			wp_deregister_script('set-post-thumbnail' );
			wp_deregister_script('imgareaselect');

			// but still reuse code for make media_upload iframe
			return wp_iframe(array(&$this, 'type_dialog'));
		}

		// Attach script and localisation text in dialog
		function add_script() {
			global $wp_scripts;
			$wp_scripts->add('pe2-script', $this->plugin_URL.'/pe2-scripts.js', array('jquery'),PE2_VERSION);
			$options = array(
				'waiting'   => str_replace('%pluginpath%', $this->plugin_URL, __("<img src='%pluginpath%/loading.gif' height='16' width='16' /> Please wait", 'pe2')),
				'env_error' => __("Error: Can not insert image(s) due wrong envirionment\nCheck script media-upload.js in the parent/editor window", 'pe2'),
				'image'     => __('Image', 'pe2'),
				'gallery'   => __('Gallery', 'pe2'),
				'thumb_w'   => get_option('thumbnail_size_w'),
				'thumb_h'   => get_option('thumbnail_size_h'),
				'thumb_crop'=> get_option('thumbnail_crop'),
				'uniqid'    => uniqid(),
			);
			foreach ( $this->options as $key => $val ) {
				$options[$key]=$val;
			}
			foreach ( $options as $key => $val ) {
				$options[$key] = rawurlencode($val);
			}
			$wp_scripts->localize( 'pe2-script', 'pe2_options', $options );

			$wp_scripts->enqueue('pe2-script');
		}

		function add_style() {
			global $is_IE;
			wp_enqueue_style('pe2-style', $this->plugin_URL.'/picasa-express-2.css',array(),PE2_VERSION,'all');
			if ($is_IE)
				wp_enqueue_style('pe2-style-ie', $this->plugin_URL.'/picasa-express-2-IE.css',array(),PE2_VERSION,'all');
		}

		function type_dialog() {
			$user_name = $this->options['pe2_user_name'];
			/*
				<a href="#" class="button alignright">Search</a>
				<form><input type="text" class="alignright" value="Search ..."/></form>
			 */
			?>
			<div id="pe2-nouser" class="pe2-header<?php echo ($user_name=='undefined')?'':' hidden'?>">
				<form><input type="text" class="alignleft" value="user name"/></form>
				<a id="pe2-change-user" href="#" class="button alignleft pe2-space"><?php _e('Change user', 'pe2')?></a>
				<a id="pe2-cu-cancel" href="#" class="button alignleft pe2-space"><?php _e('Cancel', 'pe2')?></a>
				<div id="pe2-message1" class="alignleft"></div>
				<br style="clear:both;"/>
			</div>
			<div id="pe2-albums" class="pe2-header<?php echo ($user_name=='undefined')?' hidden':''?>">
				<a id="pe2-user" href="#" class="button alignleft"><?php echo $user_name?></a>
				<div id="pe2-message2" class="alignleft"><?php _e('Select an Album', 'pe2')?></div>
				<br style="clear:both;"/>
			</div>
			<div id="pe2-images" class="pe2-header hidden">
				<a id="pe2-album-name" href="#" class="button alignleft"><?php _e('Select an Album', 'pe2')?></a>
				<div id="pe2-message3" class="alignleft"><?php _e('Select images to insert', 'pe2')?></div>

				<a id="pe2-switch" href="#" class="button alignleft"><?php _e('Image', 'pe2')?></a>
				<a id="pe2-insert" href="#" class="button alignleft pe2-space hidden"><?php _e('Insert', 'pe2')?></a>
				<br style="clear:both;"/>
			</div>
			<div id="pe2-main">
			</div>
		<?php
		}

		function get_feed($url) {
			global $wp_version;
			// add Auth later
			$options = array(
				'timeout' => ( ( defined('DOING_CRON') && DOING_CRON ) ? 30 : 3),
				'user-agent' => 'WordPress/' . $wp_version . '; ' . get_bloginfo( 'url' )
			);

			$response = wp_remote_get($url, $options);

			if ( is_wp_error( $response ) )
				return false;

			if ( 200 != $response['response']['code'] )
				return false;

			// preg sensitive for \n\n, but we not need any formating inside
			return (str_replace("\n",'',trim( $response['body'] )));
		}

		function get_item_attr($content,$tag,$attr) {
			if (!preg_match("|<$tag\s+([^>]+)/?>|u",$content,$m))
				return false;
			$a = preg_split("/[\s=]/",$m[1]);
			for ($i=0; $i<count($a); $i+=2) {
				if ($a[$i]==$attr) return trim($a[$i+1],"'\" ");
			}
			return join(',',$a);
		}
		function get_item($content,$tag,$first=false) {
			if (!preg_match_all("|<$tag(?:\s[^>]+)?>(.+?)</$tag>|u",$content,$m,PREG_PATTERN_ORDER))
				return false;
//			echo "$tag: ".count($m[1])."<br/>";
			if (count($m[1])>1 && !$first) return ($m[1]);
			else return ($m[1][0]);
		}


		function get_gallery() {

			$out = (object)array();

			if (isset($_POST['user'])) {
				$user = $_POST['user'];
			} else die();

			$rss = $this->get_feed("http://picasaweb.google.com/data/feed/base/user/$user?alt=rss&kind=album&hl=en_US");
		    if (!$this->get_item($rss,'atom:id')) {
				$out->error = __('Invalid picasa username: ', 'pe2').$user;
		    } else {
			    $items = $this->get_item($rss,'item');
			    $output = '';
			    $insert_h = (get_option('thumbnail_crop')) ? "height='144' " : '';
			    if ($items) {
			    	if (!is_array($items)) $items = array($items);
			    	$output .= "\n<table><tr>\n";
			    	$i = 0;
					foreach($items as $item) {
						// http://picasaweb.google.com/data/entry/base/user/wotttt/albumid/5408701349107410241?alt=rss&amp;hl=en_US
						$guid  = base64_encode(str_replace("entry","feed",$this->get_item($item,'guid'))."&kind=photo");
						$title = $this->get_item($item,'title');
						$desc  = $this->get_item($item,'media:description');
						$url   = $this->get_item_attr($item,'media:thumbnail','url');
						$output .= "<td><a href='#$guid'><img src='$url' alt='$desc' width='144' $insert_h/><span>$title</span></a></td>\n";
						if ($i++%4==3) $output .= "</tr><tr>\n";
					}
					$output .= "</tr></table>\n";
			    }

			    $out->items = $this->get_item($rss,'openSearch:totalResults');
			    $out->title = $this->get_item($rss,'title',true);
			    $out->data  = $output;
			    $out->cache  = $_POST['cache'];
		    }

			echo json_encode($out);
			die();
		}

		function get_images() {
			$out = (object)array();

			if (isset($_POST['guid'])) {
				$guid = base64_decode($_POST['guid']);
			} else die();

			$rss = $this->get_feed($guid);
			if (!$this->get_item($rss,'atom:id')) {
				$out->error = __('Invalid album ', 'pe2');
		    } else {
			    $items = $this->get_item($rss,'item');
		    	$output = '';
		    	$insert_h = (get_option('thumbnail_crop')) ? "height='144' " : '';
		    	$key = 1; $images = array();
		    	$sort = $this->options['pe2_img_sort'];
			    if ($items) {
			    	if (!is_array($items)) $items = array($items);
			    	foreach($items as $item) {
			    		switch ($sort) {
			    			case 0: $key++; break;
			    			case 1: $key = strtotime($this->get_item($item,'pubDate',true)); break;
			    			case 2: $key = $this->get_item($item,'title',true); break;
			    			case 3: $key = $this->get_item($item,'media:title',true); break;
			    		}
			    		$images[$key] = array (
						'guid'  => $this->get_item($item,'link'), // picasa album image
						'title' => $this->get_item($item,'title'),
						'file'  => $this->get_item($item,'media:title'),
						'desc'  => $this->get_item($item,'media:description'),
						'url'   => str_replace('s72','s288',$this->get_item_attr($item,'media:thumbnail','url')),
			    		);
			    	}
			    	if ($this->options['pe2_img_asc']) ksort($images);
			    	else krsort($images);
			    	$output .= "\n<table><tr>\n";
			    	$i = 0;
			    	foreach($images as $item) {
						$output .= "<td><a href='{$item['guid']}'><img src='{$item['url']}' alt='{$item['file']}' title='{$item['desc']}' width='144' $insert_h/><span>{$item['title']}</span></a></td>\n";
						if ($i++%4==3) $output .= "</tr><tr>\n";
					}
					$output .= "</tr></table>\n";
			    }
			    $out->items = $this->get_item($rss,'openSearch:totalResults');
			    $out->title = $this->get_item($rss,'title',true);
				$out->data  = $output;
			    $out->cache  = $_POST['cache'];
		    }

			echo json_encode($out);
			die();

		}

		function gallery_shortcode($atts, $content) {
			extract(shortcode_atts(array(
				'class' => '',
				'style' => '',
				'tag'   => 'div',
			), $atts ));

			$properties = '';
			if ($class) $properties .= "class='".esc_attr($class)."' ";
			if ($style) $properties .= "style='".esc_attr($style)."' ";

			$code = "<$tag $properties>".do_shortcode($content)."</$tag><div class='clear'></div>";

			return $code;
		}

		function clear_shortcode($atts, $content) {
			extract(shortcode_atts(array(
				'class' => '',
				'tag'   => 'div',
			), $atts ));

			$class .= (($class)?' ':'').'clear';

			$code = "<$tag class='$class'>".do_shortcode($content)."</$tag>";

			return $code;
		}

		function add_settings_link($links) {
			$settings_link = '<a href="options-general.php?page=picasa-express-2">'.__('Settings', 'pe2').'</a>';
			array_unshift( $links, $settings_link );
			return $links;
		}

		function add_settings_page() {
			add_options_page(__('Picasa Express x2', 'pe2'), __('Picasa Express x2', 'pe2'), 8, 'picasa-express-2', array(&$this, 'settings_form'));
			add_action('admin_init', array(&$this, 'settings_reg'));
			add_action('admin_print_styles-settings_page_picasa-express-2', array(&$this, 'settings_style'));
		}

		function settings_reg() {
			foreach ($this->options as $key => $option) {
				register_setting( 'picasa-express-2', $key );
			}
		}

		function settings_style() {
			wp_enqueue_style('media');
		}

		function settings_form(){
			?>
			<div class="wrap">
			<h2><?php _e('Picasa Express x2 settings', 'pe2')?></h2>

			<form method="post" action="options.php">
    			<?php settings_fields( 'picasa-express-2' ); ?>

				<input type="hidden" name="pe2_configured" value="1" />

				<table class="form-table">

					<tr valign="top">
			        <th scope="row"><?php _e('Picasa user name', 'pe2') ?></th>
			        <td><input type="text" class="regular-text" name="pe2_user_name" value="<?php echo esc_attr($this->options['pe2_user_name']); ?>" /></td>
			        </tr>

				</table>

				<h3><?php _e('Display properties', 'pe2') ?></h3>

				<table class="form-table">

					<tr valign="top">
			        <th scope="row"><?php _e('Picasa icon', 'pe2') ?></th>
			        <td>
			        	<?php
						$opts = array(
							1 => __('Picasa squire icon', 'pe2'),
							2 => __('Picasa squire grayscale icon', 'pe2'),
							3 => __('Picasa round icon', 'pe2'),
							4 => __('Picasa round grayscale icon', 'pe2'),
						);
						$option = $this->options['pe2_icon'];
			        	foreach ($opts as $i=>$text): ?>
			        	<label>
			        		<input type="radio" name="pe2_icon" value="<?php echo $i; ?>" <?php checked($option,$i) ?> />
			        		<img src="<?php echo $this->plugin_URL ?>/icon_picasa<?php echo $i; ?>.gif" alt="<?php echo $text; ?>" title="<?php echo $text; ?>"/>
			        	</label>
			        	<?php endforeach;?>
			        	<br />
			        	<span class="description"><?php _e('This icon marks the dialog activation link in the edit post page', 'pe2')?></span>
			        </td>
			        </tr>

					<tr valign="top">
			        <th scope="row"><?php _e('Sorting images in album', 'pe2') ?></th>
			        <td>
			        	<?php
						$opts = array(
							0 => __('None', 'pe2'),
							1 => __('Date', 'pe2'),
							2 => __('Title', 'pe2'),
							3 => __('File name', 'pe2'),
						);
						$option = $this->options['pe2_img_sort'];
			        	foreach ($opts as $i=>$text): ?>
			        	<label>
			        		<input type="radio" name="pe2_img_sort" value="<?php echo $i; ?>" <?php checked($option,$i) ?> />
			        		<?php echo $text; ?>
			        	</label>
			        	<?php endforeach;?>
			        	<br />
			        	<span class="description"><?php _e('This option drive image sorting in the dialog', 'pe2')?></span>
			        </td>
			        </tr>

			        <tr valign="top">
			        <th scope="row"><?php _e('Sorting order', 'pe2'); $option = $this->options['pe2_img_asc']; ?></th>
			        <td>
			        	<label><input type="radio" name="pe2_img_asc" value="1" <?php checked($option,'1') ?> /><?php _e('Ascending',  'pe2') ?></label>
			        	<label><input type="radio" name="pe2_img_asc" value="0" <?php checked($option,'0') ?> /><?php _e('Descending', 'pe2') ?></label>
			        	<br />
			        </td>
			        </tr>


				</table>

				<h3><?php _e('Image properties', 'pe2') ?></h3>
				<p><?php _e('Images from Picasa are inserted to a post as small as default thumbnail size ( you can change it <a href="options-media.php">here</a> ).')?><br/>
			       <?php _e('Image can be resized proportional with defined width or hardcoded with both width and height if "crop" checkbox is on.', 'pe2') ?></p>
				<p><?php _e('Thumbnail image can have a caption, title, link to original sized image, can be aligned and styled. Image alt property is defined by original file name.', 'pe2') ?></p>

				<table class="form-table">

					<tr valign="top">
			        <th scope="row"><?php _e('Display caption', 'pe2'); $option = $this->options['pe2_caption']; ?></th>
			        <td>
			        	<label><input type="radio" name="pe2_caption" value="1" <?php checked($option,'1') ?> /><?php _e('Yes') ?></label>
			        	<label><input type="radio" name="pe2_caption" value="0" <?php checked($option,'0') ?> /><?php _e('No') ?></label>
			        	<br />
			        	<span class="description"><?php _e('Show the caption under thumbnail image', 'pe2') ?></span>
			        </td>
			        </tr>

					<tr valign="top">
			        <th scope="row"><?php _e('Add caption as title', 'pe2'); $option = $this->options['pe2_title']; ?></th>
			        <td>
			        	<label><input type="radio" name="pe2_title" value="1" <?php checked($option,'1') ?> /><?php _e('Yes') ?></label>
			        	<label><input type="radio" name="pe2_title" value="0" <?php checked($option,'0') ?> /><?php _e('No') ?></label>
			        	<br />
			        	<span class="description"><?php _e('Show the caption by mouse hover tip', 'pe2') ?></span>
			        </td>
			        </tr>

					<tr valign="top">
			        <th scope="row"><?php _e('Link to larger image', 'pe2');  ?></th>
			        <td>
			        	<?php
			        		$opts = array (
			        			'none'     => __('No link', 'pe2'),
			        			'direct'   => __('Direct link', 'pe2'),
			        			'picasa'   => __('Link to Picasa Web Album', 'pe2'),
			        			'lightbox' => __('Lightbox', 'pe2'),
			        			'thickbox' => __('Thickbox', 'pe2'),
			        			'highslide'=> __('Highslide', 'pe2'),
			        		);
			        		$is_gallery = array (
			        			'none'     => 'false',
			        			'direct'   => 'false',
			        			'picasa'   => 'false',
			        			'lightbox' => 'true',
			        			'thickbox' => 'true',
			        			'highslide'=> 'true',
			        		);
			        		$is_gallery_js = 'var is_gallery = { ';
							foreach ($is_gallery as $key=>$val) {
								$is_gallery_js .= "$key:$val,";
							}
							$is_gallery_js = trim($is_gallery_js, ',').' };';

			        	?>
						<script type="text/javascript">
						function handle_gallery_properties(t) {
							<?php echo $is_gallery_js; ?>

							if (is_gallery[t]) {
								jQuery('#gallery_properties').show();
								jQuery('#nogallery_properties').hide();
							} else {
								jQuery('#gallery_properties').hide();
								jQuery('#nogallery_properties').show();
							}
						}
						</script>
			        	<select name="pe2_link" onchange="handle_gallery_properties(this.value);">
			        	<?php
			        		$option = $this->options['pe2_link'];
							foreach ($opts as $key => $val ):
			        	?>
			        		<option value="<?php echo $key ?>" <?php selected($option,$key ); ?>><?php echo $val ?></option>
			        	<?php endforeach;?>
			        	</select>
			        	<br />
			        </td>
			        </tr>

			        <tr valign="top">
			        <th scope="row"><?php _e('Image alignment', 'pe2');  ?></th>
			        <td>
			        	<?php
			        		$opts = array (
			        			'none'   => __('None'),
			        			'left'   => __('Left'),
			        			'center' => __('Center'),
			        			'right'  => __('Right'),
			        		);
			        		$option = $this->options['pe2_img_align'];
							foreach ($opts as $key => $val ):
			        	?>
							<input type="radio" name="pe2_img_align" id="align<?php echo $key ?>" value="<?php echo $key ?>" <?php checked($option,$key); ?> />
							<label for="align<?php echo $key ?>" style="padding-left:22px;margin-right:13px;" class="image-align-<?php echo $key ?>-label"><?php echo $val ?></label>
						<?php endforeach; ?>
			        </td>
			        </tr>

					<tr valign="top">
			        <th scope="row"><?php _e('CSS Class', 'pe2'); ?></th>
			        <td>
			        	<input type="text" name="pe2_img_css" class="regular-text" value="<?php echo esc_attr($this->options['pe2_img_css']); ?>"/>
			        	<br />
			        	<span class="description"><?php _e("You can define default class for images from theme's style.css", 'pe2') ?></span>
			        </td>
			        </tr>

					<tr valign="top">
			        <th scope="row"><?php _e('Style', 'pe2'); ?></th>
			        <td>
			        	<input type="text" name="pe2_img_style" class="regular-text" value="<?php echo esc_attr($this->options['pe2_img_style']); ?>"/>
			        	<br />
			        	<span class="description"><?php _e('You can hardcode some css attributes', 'pe2') ?></span>
			        </td>
			        </tr>

				</table>

				<h3><?php _e('Gallery properties', 'pe2') ?></h3>
				<p>
				<?php _e('Images can be grouped into gallery by Lightbox,Thickbox or Highslide and viewed sequentially with embedded navigation', 'pe2') ?>
				<br />
				<?php _e('Plugin can orginize the group by aligning or apply CSS style or class', 'pe2') ?>
				</p>

			<div id="nogallery_properties" style="<?php echo ($is_gallery[$this->options['pe2_link']]=='true') ? 'display:none;' : 'display:block;'?>">
				<p><?php _e('To view and change properties you have to select Thickbox, Lightbox or Highslide support for the images above', 'pe2') ?></p>
			</div>
			<div id="gallery_properties" style="<?php echo ($is_gallery[$this->options['pe2_link']]=='false') ? 'display:none;' : 'display:block;'?>">

				<table class="form-table">

			        <tr valign="top">
			        <th scope="row"><?php _e('Selection order', 'pe2'); $option = $this->options['pe2_gal_order']; ?></th>
			        <td>
			        	<label><input type="radio" name="pe2_gal_order" value="1" <?php checked($option,'1') ?> /><?php _e('Yes') ?></label>
			        	<label><input type="radio" name="pe2_gal_order" value="0" <?php checked($option,'0') ?> /><?php _e('No') ?></label>
			        	<br />
			        	<span class="description"><?php _e("Click images in your preferred order", 'pe2') ?></span>
			        </td>
			        </tr>

			        <tr valign="top">
			        <th scope="row"><?php _e('Gallery alignment', 'pe2');  ?></th>
			        <td>
			        	<?php
			        		$opts = array (
			        			'none'   => __('None'),
			        			'left'   => __('Left'),
			        			'center' => __('Center'),
			        			'right'  => __('Right'),
			        		);
			        		$option = $this->options['pe2_gal_align'];
							foreach ($opts as $key => $val ):
			        	?>
							<input type="radio" name="pe2_gal_align" id="align<?php echo $key ?>" value="<?php echo $key ?>" <?php checked($option,$key); ?> />
							<label for="align<?php echo $key ?>" style="padding-left:22px;margin-right:13px;" class="image-align-<?php echo $key ?>-label"><?php echo $val ?></label>
						<?php endforeach; ?>
			        </td>
			        </tr>

					<tr valign="top">
			        <th scope="row"><?php _e('CSS Class', 'pe2'); ?></th>
			        <td>
			        	<input type="text" name="pe2_gal_css" class="regular-text" value="<?php echo esc_attr($this->options['pe2_gal_css']); ?>"/>
			        	<br />
			        	<span class="description"><?php _e("You can define default class for images from theme's style.css", 'pe2') ?></span>
			        </td>
			        </tr>

					<tr valign="top">
			        <th scope="row"><?php _e('Style', 'pe2'); ?></th>
			        <td>
			        	<input type="text" name="pe2_gal_style" class="regular-text" value="<?php echo esc_attr($this->options['pe2_gal_style']); ?>"/>
			        	<br />
			        	<span class="description"><?php _e('You can hardcode some css attributes', 'pe2') ?></span>
			        </td>
			        </tr>

				</table>
			</div>

				<p class="submit">
			    <input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
			    </p>

			</form>
			</div>
			<?php
		}
	}
}

if (!isset($pe2_instance)) $pe2_instance = new PicasaExpressX2();

?>